==> elasticsearch-ruby-9.0.2.tar.gz: elasticsearch-ruby-9.0.2/elasticsearch-api/spec/unit/actions/indices/analyze_spec.rb <==
# Licensed to Elasticsearch B.V. under one or more contributor
# license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

require 'spec_helper'

describe 'client.indices#analyze' do
  let(:expected_args) do
    [
      method,
      url,
      params,
      body,
      {},
      { endpoint: 'indices.analyze' }
    ]
  end
  let(:method) { 'GET' }

  let(:body) do
    nil
  end

  let(:url) do
    '_analyze'
  end

  let(:params) do
    {}
  end

  it 'performs the request' do
    expect(client_double.indices.analyze).to be_a Elasticsearch::API::Response
  end

  context 'when an index is specified' do
    let(:url) do
      'foo/_analyze'
    end

    let(:expected_args) do
      [
        method,
        url,
        params,
        body,
        {},
        { defined_params: { index: 'foo' }, endpoint: 'indices.analyze' }
      ]
    end

    it 'performs the request' do
      expect(client_double.indices.analyze(index: 'foo')).to be_a Elasticsearch::API::Response
    end
  end

  context 'when a body is specified' do
    let(:body) do
      'foo'
    end
    let(:method) { 'POST' }

    it 'performs the request' do
      expect(client_double.indices.analyze(body: 'foo')).to be_a Elasticsearch::API::Response
    end
  end
end

==> elasticsearch-ruby-9.2.0.tar.gz: elasticsearch-ruby-9.2.0/elasticsearch-api/spec/unit/actions/indices/analyze_spec.rb <==
# Licensed to Elasticsearch B.V. under one or more contributor
# license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

require 'spec_helper'

describe 'client.indices#analyze' do
  let(:expected_args) do
    [
      method,
      url,
      params,
      body,
      {},
      { endpoint: 'indices.analyze' }
    ]
  end
  let(:method) { 'POST' }

  let(:body) do
    {}
  end

  let(:url) do
    '_analyze'
  end

  let(:params) do
    {}
  end

  it 'performs the request' do
    expect(client_double.indices.analyze(body: {})).to be_a Elasticsearch::API::Response
  end

  context 'when an index is specified' do
    let(:url) do
      'foo/_analyze'
    end

    let(:expected_args) do
      [
        method,
        url,
        params,
        body,
        {},
        { defined_params: { index: 'foo' }, endpoint: 'indices.analyze' }
      ]
    end

    it 'performs the request' do
      expect(client_double.indices.analyze(index: 'foo', body: {})).to be_a Elasticsearch::API::Response
    end
  end
end
